@@ -2,6 +2,7 @@ import os
 import subprocess
 import sys
 
+import django
 from django.apps import apps
 from django.conf import settings
 from django.contrib.auth.hashers import make_password
@@ -14,7 +15,7 @@ from psycopg2.extensions import ISOLATION_LEVEL_SERIALIZABLE
 class Command(BaseCommand):
     help = "Prints a (sort of) pg_dump of the db with sensitive data masked."
 
-    requires_system_checks = False
+    requires_system_checks = [] if django.VERSION >= (3, 2) else False
 
     def add_arguments(self, parser):
         parser.add_argument(
